@@ -95,13 +95,13 @@ L<IO::Handle|SPVM::IO::Handle>.
 
   method ungetc : int ($c : int);
 
-=head2 syswrite
+=head2 write
 
-  method syswrite : int ($buffer : string, $length : int, $offset : int = 0);
+  method write : int ($string : string, $length : int = -1, $offset : int = 0);
 
-=head2 sysread
+=head2 read
 
-  method sysread : int ($buffer : mutable string, $length : int, $offset : int = 0);
+  method read : int ($string : mutable string, $length : int = -1, $offset : int = 0);
 
 =head1 See Also
 
